<template>
    <div  class="copy-container">
        <input id="link" :value="value" readonly>
        <div id="copy" @click="copyToClipboard($event)">
            <i class="fa fa-clipboard" aria-hidden="true" data-copytarget="#link"></i>
        </div>
    </div>
</template>

<script>
    export default {
        name: "CopyToClipboard",
        props:{
            value:{
                type:String,
                default:''
            }
        },
        methods:{
            copyToClipboard(e) {
                // alert('this function was triggered');
                // find target element
                var
                    t = e.target,
                    c = t.dataset.copytarget,
                    inp = (c ? document.querySelector(c) : null);
                // console.log(inp);
                // check if input element exist and if it's selectable
                if (inp && inp.select) {
                    // select text
                    inp.select();
                    try {
                        // copy text
                        document.execCommand('copy');
                        inp.blur();

                        // copied animation
                        t.classList.add('copied');
                        setTimeout(function() {
                            t.classList.remove('copied');
                        }, 1500);
                    } catch (err) {
                        //fallback in case exexCommand doesnt work
                        alert('please press Ctrl/Cmd+C to copy');
                    }

                }

            }
        }
    }
</script>

<style lang="scss">
   .copy-container {
        box-sizing: border-box;
        display: flex;
        flex-direction: row;
        background-color: #fff;
        border: 1px solid #ccc;
        padding: 10px;
        margin-bottom: 10px;
        border-radius: 5px;
        justify-content: space-between;
        width: 100%;
        box-shadow: 0px 1px 2px rgba(0,0,0,.07);
        #link {
            align-self: center;
            font-size: 1.2em;
            color: #333;
            font-weight: bold;
            flex-grow: 2;
            background-color: #fff;
            border: none;
        }
        #copy {
            width: 30px;
            height: 30px;
            margin-left: 20px;
            border: 1px solid #ccc;
            border-radius: 5px;
            background-color: #f8f8f8;
            i {
                display: block;
                line-height: 30px;
                position: relative;
                &::before {
                    display: block;
                    width: 15px;
                    margin: 0 auto;
                }
                &.copied::after {
                    position: absolute;
                    top: 0px;
                    right: 35px;
                    height: 30px;
                    line-height: 25px;
                    display: block;
                    content: "copied";
                    font-size: 1.5em;
                    padding: 2px 10px;
                    color: #fff;
                    background-color: #4099FF;
                    border-radius: 3px;
                    opacity: 1;
                    will-change: opacity, transform;
                    animation: showcopied 1.5s ease;
                }
            }
            &:hover {
                cursor: pointer;
                background-color: darken(#f8f8f8, 10%);
                transition: background-color .3s ease-in;
            }
        }
    }

    @keyframes showcopied {
        0% {
            opacity: 0;
            transform: translateX(100%);
        }
        70% {
            opacity: 1;
            transform: translateX(0);
        }
        100% {
            opacity: 0;
        }
    }
</style>